3440 Vasil Dimov 2011-09-27
Improve comment and add a debug assertion in
innobase_get_mysql_key_number_for_index()
Discussed with: Jimmy (over IM)
modified:
storage/innobase/handler/ha_innodb.cc
3439 Luis Soares 2011-09-26
BUG#12978113: MTS: TYPOS IN LOGGING TO THE SLAVE ERROR LOG
BUG#12947248: MTS: WARNING "TEMPORARY FAILED TRANSACTION
RETRY IS NOT SUPPORTED" IS MISPLACED
There were a couple of typos and unclear messages. We fix this
by:
- rewriting the warning message output when the start slave
command is issued;
- fixed the existing typo
In addition we also:
- rewrote one information note that goes into the error log
- limit the MTS info messages that end to the error log by
only allowing them when log_warnings > 1.
modified:
mysql-test/suite/rpl/r/rpl_parallel_start_stop.result
sql/rpl_rli_pdb.cc
sql/rpl_slave.cc
=== modified file 'storage/innobase/handler/ha_innodb.cc'
--- a/storage/innobase/handler/ha_innodb.cc revid:luis.soares@stripped
+++ b/storage/innobase/handler/ha_innodb.cc revid:vasil.dimov@stripped
@@ -8295,9 +8295,11 @@ innobase_get_mysql_key_number_for_index(
unsigned int i;
ut_a(index);
+ ut_ad(strcmp(index->table->name, ib_table->name) == 0);
- /* If index does not belong to the table of share structure. Search
- index->table instead */
+ /* If index does not belong to the table object of share structure
+ (ib_table comes from the share structure) search the index->table
+ object instead */
if (index->table != ib_table) {
i = 0;
ind = dict_table_get_first_index(index->table);
No bundle (reason: useless for push emails).
| Thread |
|---|
| • bzr push into mysql-trunk branch (vasil.dimov:3439 to 3440) | vasil.dimov | 29 Sep |